summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorpmoody@google.com <pmoody@google.com@09200d28-7f98-11dd-ad27-0f66e57d2035>2010-03-02 17:44:50 +0000
committerpmoody@google.com <pmoody@google.com@09200d28-7f98-11dd-ad27-0f66e57d2035>2010-03-02 17:44:50 +0000
commitf5235a186e01a366eb60a0c8fbdfbbfdd4b1adad (patch)
tree90f9b6b795dcdd2ce9f9b77cd9237866a074a8c3
parent34acff7cd9fabb4069d1dce7c48dcd51410ab6dc (diff)
downloadipaddr-py-f5235a186e01a366eb60a0c8fbdfbbfdd4b1adad.tar.gz
+ merging changes from trunk.
git-svn-id: https://ipaddr-py.googlecode.com/svn@153 09200d28-7f98-11dd-ad27-0f66e57d2035
-rw-r--r--branches/2.1.x/ipaddr.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/branches/2.1.x/ipaddr.py b/branches/2.1.x/ipaddr.py
index 7e7cb0c..5ebf8c8 100644
--- a/branches/2.1.x/ipaddr.py
+++ b/branches/2.1.x/ipaddr.py
@@ -1685,7 +1685,7 @@ class _BaseV6(object):
return None
try:
return IPv4Address(int('%s%s' % (hextets[-2], hextets[-1]), 16))
- except IPv4IpvalidationError:
+ except AddressValueError:
return None
@@ -1708,7 +1708,7 @@ class IPv6Address(_BaseV6, _BaseIP):
IPv6Address('2001:4860::')
Raises:
IPv6IpValidationError: If address isn't a valid IPv6 address.
"""
_BaseIP.__init__(self, address)
@@ -1708,7 +1708,7 @@ class IPv6Address(_BaseV6, _BaseIP):
IPv6Address('2001:4860::')
Raises:
- IPv6IpValidationError: If address isn't a valid IPv6 address.
+ AddressValueError: If address isn't a valid IPv6 address.
"""
_BaseIP.__init__(self, address)